@@ -1,7 +1,7 @@
 package App::podtohtml;
 
 our $DATE = '2018-09-11'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,21 +18,21 @@ sub _list_templates_or_get_template_tarball {
     my $which = shift;
 
     my @dirs = (
-        "$Bin/../share/templates",
+        "$CWD/share",
+        "$Bin/../share",
         File::ShareDir::dist_dir('App-podtohtml'),
-        "$CWD/share/templates",
     );
     my %templates;
     for my $dir (@dirs) {
-        next unless -d $dir;
-        local $CWD = $dir;
+        next unless -d "$dir/templates";
+        local $CWD = "$dir/templates";
         for my $e (glob "*.tar") {
             my ($name) = $e =~ /(.+)\.tar$/;
             if ($which eq 'list_templates') {
                 $templates{$name}++;
             } elsif ($which eq 'get_template_tarball') {
                 if ($name eq $_[0]) {
-                    return "$dir/$e";
+                    return "$CWD/$e";
                 }
             }
         }
@@ -62,7 +62,7 @@ $SPEC{podtohtml} = {
 This is a thin wrapper for <pm:Pod::Html> and an alternative CLI to
 <prog:pod2html> to remove some annoyances that I experience with `pod2html`,
 e.g. the default cache directory being `.` (so it leaves `.tmp` files around).
-This CLI also offers tab completion.
+This CLI also offers templates and tab completion.
 
 It does not yet offer as many options as `pod2html`.
 
@@ -102,6 +102,15 @@ _
             schema => ['str*'],
             cmdline_aliases => {t=>{}},
             tags => ['category:template'],
+            completion => sub {
+                require App::podtohtml; # this weird thing is when we are run in _podtohtml
+                require Complete::Util;
+                my %args = @_;
+                Complete::Util::complete_array_elem(
+                    word => $args{word},
+                    array => App::podtohtml::_list_templates(),
+                );
+            },
         },
     },
     args_rels => {
@@ -233,7 +242,7 @@ App::podtohtml - Convert POD to HTML
 
 =head1 VERSION
 
-This document describes version 0.005 of App::podtohtml (from Perl distribution App-podtohtml), released on 2018-09-11.
+This document describes version 0.006 of App::podtohtml (from Perl distribution App-podtohtml), released on 2018-09-11.
 
 =head1 FUNCTIONS
 
@@ -283,7 +292,7 @@ Examples:
 This is a thin wrapper for L<Pod::Html> and an alternative CLI to
 L<pod2html> to remove some annoyances that I experience with C<pod2html>,
 e.g. the default cache directory being C<.> (so it leaves C<.tmp> files around).
-This CLI also offers tab completion.
+This CLI also offers templates and tab completion.
 
 It does not yet offer as many options as C<pod2html>.
 
